@@ -1,9 +1,9 @@
 package List::Util::Find;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-05-26'; # DATE
+our $DATE = '2021-06-10'; # DATE
 our $DIST = 'List-Util-Find'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -65,7 +65,7 @@ List::Util::Find - List utilities related to finding items
 
 =head1 VERSION
 
-This document describes version 0.002 of List::Util::Find (from Perl distribution List-Util-Find), released on 2021-05-26.
+This document describes version 0.003 of List::Util::Find (from Perl distribution List-Util-Find), released on 2021-06-10.
 
 =head1 SYNOPSIS
 
@@ -95,8 +95,9 @@ Usage:
 
  hasnum $num, ...
 
-Like C<< grep { $_ == $num } ... >> except: 1) it makes sure C<undef> does not
-match; 2) it makes sure non-numeric scalars don't match when C<$num> is zero.
+Like C<< grep { $_ == $num } ... >> except: 1) it short-circuits (exits early as
+soon as an item is found); 2) it makes sure C<undef> does not match; 3) it makes
+sure non-numeric scalars don't match when C<$num> is zero.
 
 =head2 hasstr
 
@@ -104,8 +105,9 @@ Usage:
 
  hasstr $str, ...
 
-Like C<< grep { $_ eq $num } ... >> except: 1) it makes sure C<undef> does not
-match empty string.
+Like C<< grep { $_ eq $num } ... >> except: 1) it short-circuits (exits early as
+soon as an item is found); 2) it makes sure C<undef> does not match empty
+string.
 
 =head1 HOMEPAGE
 
